==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/BulkAsyncInteraction.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkAsyncInteraction]
AS
BEGIN
	-- ESTE SP INSERTA REGISTROS UNICOS DE ASYNCINTERACTION PROVENIENTES DE LA BD EXTERNA EN LA TABLA ASYNCINTERACTION Y PROCESSASYNCINTERACTION

	--
	INSERT INTO [dbo].[AsyncInteraction] (
		[VCC], [ID], [Folder], [ExportedContent], [Channel]
		, [Campaign], [StartDate], [EndDate], [Account], [Initiative]
		, [ContactName], [FirstTakedAgent], [LastTakedAgent], [IsTaken], [TotalMessages]
		, [DurationTime], [AttentionTime], [DispositionCode], [DispositionTreePath], [RawChar] 
		, [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]
	)
		-- SELECCIONAMOS TODOS LOS REGISTROS DE LA TABLA TEMPORAL [#AsyncInteractionTemp] QUE NO EXISTEN EN [AsyncInteraction] POR LOS PK
		SELECT AIT.[VCC], AIT.[ID], AIT.[Folder], AIT.[ExportedContent], AIT.[Channel]
				, AIT.[Campaign], AIT.[StartDate], AIT.[EndDate], AIT.[Account], AIT.[Initiative]
				, AIT.[ContactName], AIT.[FirstTakedAgent], AIT.[LastTakedAgent], AIT.[IsTaken], AIT.[TotalMessages]
				, AIT.[DurationTime], AIT.[AttentionTime], AIT.[DispositionCode], AIT.[DispositionTreePath], AIT.[RawChar]
				, AIT.[CreatedDate], AIT.[CreatedByUserId], AIT.[LastModifiedDate], AIT.[LastModifiedByUserId], GETUTCDATE()
			FROM [#AsyncInteractionTemp] AIT
			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = AIT.[VCC]
					AND AI.[ID] = AIT.[ID]
					AND CONVERT(VARCHAR, AI.[EndDate], 23) = AIT.[Folder]
			WHERE AI.[ID] IS NULL

	--
	INSERT INTO [dbo].[ProcessAsyncInteraction] (
		[VCC], [ProcessId], [InteractionType], [Campaign], [InteractionId]
		, [EndDate], [FormattedEndDate], [CreatedDate], [CreatedByUserId], [LastModifiedDate]
		, [LastModifiedByUserId], [TimeStamp]
	)
		-- SELECCIONAMOS TODOS LOS REGISTROS DE LA TABLA TEMPORAL [#ProcessAsyncInteractionTemp] QUE NO EXISTEN EN [ProcessAsyncInteraction] POR LOS PK
		SELECT PAIT.[VCC], PAIT.[ProcessId], PAIT.[InteractionType], PAIT.[Campaign], PAIT.[InteractionId] 
				, PAIT.[EndDate], PAIT.[FormattedEndDate], PAIT.[CreatedDate], PAIT.[CreatedByUserId], PAIT.[LastModifiedDate]
				, PAIT.[LastModifiedByUserId], GETUTCDATE()
			FROM [#ProcessAsyncInteractionTemp] PAIT
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = PAIT.[VCC]
					AND PAI.[ProcessId] = PAIT.[ProcessId]
					AND PAI.[InteractionType] = PAIT.[InteractionType]
					AND PAI.[InteractionId] = PAIT.[InteractionId]
					--AND PAI.[EndDate] = PAIT.[EndDate]
					AND PAI.[FormattedEndDate] = PAIT.[FormattedEndDate]
			WHERE PAI.[InteractionId] IS NULL
	
	-- ELIMINAMOS LAS TABLAS TEMPORALES
	DROP TABLE [#AsyncInteractionTemp]
	DROP TABLE [#ProcessAsyncInteractionTemp]
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/BulkAsyncInteraction.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkAsyncInteraction]
AS
BEGIN
	-- ESTE SP INSERTA REGISTROS UNICOS DE ASYNCINTERACTION PROVENIENTES DE LA BD EXTERNA EN LA TABLA ASYNCINTERACTION Y PROCESSASYNCINTERACTION

	--
	INSERT INTO [dbo].[AsyncInteraction] (
		[VCC], [ID], [Folder], [ExportedContent], [Channel]
		, [Campaign], [StartDate], [EndDate], [Account], [Initiative]
		, [ContactName], [FirstTakedAgent], [LastTakedAgent], [FirstTakedAgentName], [LastTakedAgentName]
		, [IsTaken], [TotalMessages], [DurationTime], [AttentionTime], [DispositionCode]
		, [DispositionTreePath], [RawChar], [CreatedDate], [CreatedByUserId], [LastModifiedDate]
		, [LastModifiedByUserId], [TimeStamp]
	)
		-- SELECCIONAMOS TODOS LOS REGISTROS DE LA TABLA TEMPORAL [#AsyncInteractionTemp] QUE NO EXISTEN EN [AsyncInteraction] POR LOS PK
		SELECT AIT.[VCC], AIT.[ID], AIT.[Folder], AIT.[ExportedContent], AIT.[Channel]
				, AIT.[Campaign], AIT.[StartDate], AIT.[EndDate], AIT.[Account], AIT.[Initiative]
				, AIT.[ContactName], AIT.[FirstTakedAgent], AIT.[LastTakedAgent], A1.[Name], A2.[Name]
				, AIT.[IsTaken], AIT.[TotalMessages], AIT.[DurationTime], AIT.[AttentionTime], AIT.[DispositionCode]
				, AIT.[DispositionTreePath], AIT.[RawChar], AIT.[CreatedDate], AIT.[CreatedByUserId], AIT.[LastModifiedDate]
				, AIT.[LastModifiedByUserId], GETUTCDATE()
			FROM [#AsyncInteractionTemp] AIT
			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = AIT.[VCC]
					AND AI.[ID] = AIT.[ID]
					AND CONVERT(VARCHAR, AI.[EndDate], 23) = AIT.[Folder]
			LEFT JOIN [dbo].[Agent] A1 (NOLOCK)
				ON A1.[VCC] = AIT.[VCC]
					AND A1.[AgentId] = AIT.[FirstTakedAgent]
			LEFT JOIN [dbo].[Agent] A2 (NOLOCK)
				ON A2.[VCC] = AIT.[VCC]
					AND A2.[AgentId] = AIT.[LastTakedAgent]
			WHERE AI.[ID] IS NULL

	--
	INSERT INTO [dbo].[ProcessAsyncInteraction] (
		[VCC], [ProcessId], [InteractionType], [Campaign], [InteractionId]
		, [EndDate], [FormattedEndDate], [CreatedDate], [CreatedByUserId], [LastModifiedDate]
		, [LastModifiedByUserId], [TimeStamp]
	)
		-- SELECCIONAMOS TODOS LOS REGISTROS DE LA TABLA TEMPORAL [#ProcessAsyncInteractionTemp] QUE NO EXISTEN EN [ProcessAsyncInteraction] POR LOS PK
		SELECT PAIT.[VCC], PAIT.[ProcessId], PAIT.[InteractionType], PAIT.[Campaign], PAIT.[InteractionId] 
				, PAIT.[EndDate], PAIT.[FormattedEndDate], PAIT.[CreatedDate], PAIT.[CreatedByUserId], PAIT.[LastModifiedDate]
				, PAIT.[LastModifiedByUserId], GETUTCDATE()
			FROM [#ProcessAsyncInteractionTemp] PAIT
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = PAIT.[VCC]
					AND PAI.[ProcessId] = PAIT.[ProcessId]
					AND PAI.[InteractionType] = PAIT.[InteractionType]
					AND PAI.[InteractionId] = PAIT.[InteractionId]
					--AND PAI.[EndDate] = PAIT.[EndDate]
					AND PAI.[FormattedEndDate] = PAIT.[FormattedEndDate]
			WHERE PAI.[InteractionId] IS NULL
	
	-- ELIMINAMOS LAS TABLAS TEMPORALES
	DROP TABLE [#AsyncInteractionTemp]
	DROP TABLE [#ProcessAsyncInteractionTemp]
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
